==> NaxToPy-1.1.1-py3-none-any.whl: NaxToPy/Core/Classes/N2PIncrement.py <==
# Clase Increment de Python --------------------------------------------------------------------------------------------
class N2PIncrement:
    '''Class which contains the information associated to an increment/frame of a N2PLoadCase instance.

    Attributes:
        Name: str
        ImaginaryEigenvalue: float
        RealEigenvalue: float
        ID: int
        Time: double
    '''

    # Constructor de N2PIncrement --------------------------------------------------------------------------------------
    def __init__(self, name, eigi, eigr, number, time):
        '''Python Increment Constructor
            Input:
                name: str -> name of the increment
                eigi: double -> value of the imaginary eigenvalue
                eigr: double -> value of the real eigenvalue
                number: int -> number of the increment within the sequence of increments in the load case
                time: double -> value of the increment
            ----------
            Returns:
                N2PIncrement: object
        '''
        self.__name__ = name
        self.__eigi__ = eigi
        self.__eigr__ = eigr
        self.__number__ = number
        self.__time__ = time
    # ------------------------------------------------------------------------------------------------------------------

    # Metodo para obtener el nombre del incremento ---------------------------------------------------------------------
    @property
    def Name(self) -> str:
        return(str(self.__name__))
    # ------------------------------------------------------------------------------------------------------------------

    # Metodo para obtener el valor del autovalor real ------------------------------------------------------------------
    @property
    def RealEigenvalue(self) -> float:
        return(float(self.__eigr__))
    # ------------------------------------------------------------------------------------------------------------------

    # Metodo para obtener el valor del autovalor imaginario ------------------------------------------------------------
    @property
    def ImaginaryEigenvalue(self) -> float:
        return(float(self.__eigi__))
    # ------------------------------------------------------------------------------------------------------------------

    # Metodo para obtener el ID del incremento en el caso de carga -----------------------------------------------------
    @property
    def ID(self) -> int:
        return(int(self.__number__))
    # ------------------------------------------------------------------------------------------------------------------

    # Metodo para obtener el valor del incremento ----------------------------------------------------------------------
    @property
    def Time(self) -> float:
        ''' Returns the value of the increment/frame'''
        return(float(self.__time__))
    # ------------------------------------------------------------------------------------------------------------------

    # Special Method for Object Representation -------------------------------------------------------------------------
    def __repr__(self):
        return f"N2PIncrement({self.ID}: \"{self.Name}\")"
    # ------------------------------------------------------------------------------------------------------------------

# ----------------------------------------------------------------------------------------------------------------------

==> NaxToPy-2.1.2-py3-none-any.whl: NaxToPy/Core/Classes/N2PIncrement.py <==
# Clase Increment de Python --------------------------------------------------------------------------------------------
class N2PIncrement:
    """Class which contains the information associated to an increment/frame of a N2PLoadCase instance."""

    # Constructor de N2PIncrement --------------------------------------------------------------------------------------
    def __init__(self, info):
        self.__info__ = info
    # ------------------------------------------------------------------------------------------------------------------

    # Metodo para obtener el nombre del incremento ---------------------------------------------------------------------
    @property
    def Name(self) -> str:
        """Name of the Increment"""
        return(str(self.__info__.Name))
    # ------------------------------------------------------------------------------------------------------------------

    # Metodo para obtener el valor del autovalor real ------------------------------------------------------------------
    @property
    def RealEigenvalue(self) -> float:
        """Real Eigenvalue of the increment"""
        return(float(self.__info__.EigReal))
    # ------------------------------------------------------------------------------------------------------------------

    # Metodo para obtener el valor del autovalor imaginario ------------------------------------------------------------
    @property
    def ImaginaryEigenvalue(self) -> float:
        """Imaginary Eigenvalue of the increment"""
        return(float(self.__info__.EigImg))
    # ------------------------------------------------------------------------------------------------------------------

    # Metodo para obtener el ID del incremento en el caso de carga -----------------------------------------------------
    @property
    def ID(self) -> int:
        """Solver ID of the Increment"""
        return(int(self.__info__.ID))
    # ------------------------------------------------------------------------------------------------------------------

    # Metodo para obtener el valor del incremento ----------------------------------------------------------------------
    @property
    def Time(self) -> float:
        ''' Returns the value of the increment/frame'''
        return(float(self.__info__.Time))
    # ------------------------------------------------------------------------------------------------------------------

    # Metodo para obtener el tipo de Solucion --- ----------------------------------------------------------------------
    @property
    def Solution(self) -> str:
        """Returns the value of the Solution name of the Increment"""
        return(str(self.__info__.Solution))
    # ------------------------------------------------------------------------------------------------------------------

    # Special Method for Object Representation -------------------------------------------------------------------------
    def __repr__(self):
        return f"N2PIncrement({self.ID}: \"{self.Name}\")"
    # ------------------------------------------------------------------------------------------------------------------

# ----------------------------------------------------------------------------------------------------------------------
